Features
========

.. meta::
    :description: DataLab features
    :keywords: DataLab, features, signal processing, image processing

DataLab features are detailed in the following sections. The first section
describes the general features of DataLab, then the two following sections
describe the features specific to the signal and image processing panels.

Before jumping into the details of other parts of the documentation, it is
recommended to start with the :ref:`workspace` page, which describes the
basic concepts of DataLab.

.. seealso::

    For a synthetic overview of the features of DataLab, please refer to the
    :ref:`key_features` page.

General features
----------------

This section describes the general features of DataLab, which concern both the
signal and image processing panels.

.. figure:: /images/DataLab-Screenshot.png

    DataLab main window

.. toctree::
   :maxdepth: 2
   :caption: General features:

   general/validation
   general/workspace
   general/h5browser
   general/macros
   general/remote
   general/model
   general/plugins
   general/logviewer
   general/instviewer
   general/settings
   general/command

.. raw:: latex

    \newpage

Signal processing
-----------------

This section describes the features specific to the signal processing panel. The
signal processing panel is the default panel when DataLab is started.

.. figure:: /images/shots/s_beautiful.png

    DataLab main window: Signal processing view

.. toctree::
   :maxdepth: 2
   :caption: Signal processing:

   signal/menu_file
   signal/menu_operations
   signal/menu_processing
   signal/menu_computing
   signal/menu_view

.. raw:: latex

    \newpage

Image processing
----------------

This section describes the features specific to the image processing panel. The
image processing panel can be selected by clicking on the "Images" tab at the
bottom-right of the DataLab main window.

.. figure:: /images/shots/i_beautiful.png

    DataLab main window: Image processing view

.. toctree::
   :maxdepth: 2
   :caption: Image processing:

   image/menu_file
   image/menu_operations
   image/menu_processing
   image/menu_computing
   image/menu_view
   image/2d_peak_detection
   image/contour_detection
